           
****************************************************
****** 			Locking Down Violence		  ******
******.   Brancati, Birnir, and Idlbi 	      ******
******  		Appendix Models 		      ******
****************************************************


********************************************************************************************************
********************************************************************************************************
****************************************** I. NATIONAL-LEVEL ANALYSIS **********************************
********************************************************************************************************
******************************************************************************************************** 

clear
use "LDV_NATLEVEL.dta"

*Time-Set the Data
gen monthnoyear = monthno
replace monthnoyear  = monthno + 12 if year == 2020 
move monthno monthnoyear 
browse if monthnoyear == .
drop if monthnoyear == .

xtset monthnoyear 

*Generate Country Fixed Effects 
gen syria  = 0 
replace syria = 1 if iso == 760 
gen iraq = 0 
replace iraq = 1 if iso  == 368
gen egypt = 0 
replace egypt = 1 if iso  == 818

*Generate lags*

sort iso week 
foreach  variable of varlist  ramadan covid19eracase covid19eradeath oilprice uscovid19eradeath uscovidcumdeathcdc uscovidcumdeathdatecdc uscovidcumdeathswho internalbanstri curfewsdi curfewstri neighbanstri covidcumdeathswho covidcumdeathsdatewho usforces iranforces sdfforces gosforces goiforces pmfforces goeforces securityaidtotal economicaidusaid humanitarianaidunfts covidaidunfts covidaidstate internalbansdi neighbansdi neighbansdi2 ISIScurfewsdi nonISIScurfewsdi nonISISnternalbansdi nonISISneighbansdi {
bysort iso: gen `variable'_lag = `variable'[_n-1]
}
destring, replace

************************************************************* ANALYSIS ********************************************************************** 


**A3. NATIONAL LEVEL INTERACTIONS WITH OTHER COUNTRIES**
gen covid19eradeathlag_syria = covid19eradeath_lag*syria
gen covid19eradeathlag_egypt = covid19eradeath_lag*egypt

xtnbreg isisandlikely_wk covid19eradeath_lag covid19eradeathlag_syria vsisis_wklag oilprice_lag ramadan iraq syria, re
outreg2 using 1.OTHRCNTYIX.doc, replace e(ll) 2aster bdec(2) sdec(2) bfmt(f) ctitle("all events")  title("National-level Country Interactions-Syria and Iraq") 
asdoc test covid19eradeathlag_syria syria covid19eradeath_lag, replace save(1.OTHRCNTYIX_tests.doc) title(Model 1 Wald Test)
asdoc margins, at(covid19eradeathlag_syria=0 covid19eradeath_lag=0 iraq=0 syria=1), append save(1.OTHRCNTYIX_tests.doc) title(Model 1 Marginal Effects)
asdoc margins, at(covid19eradeathlag_syria=1 covid19eradeath_lag=1 iraq=0 syria=1), append save(1.OTHRCNTYIX_tests.doc) title(Model 1 Marginal Effects)

xtnbreg isisandlikely_wk covid19eradeath_lag covid19eradeathlag_egypt  vsisis_wklag oilprice_lag ramadan iraq egypt, re
outreg2 using 1.OTHRCNTYIX.doc, append e(ll) 2aster bdec(2) sdec(2) bfmt(f) ctitle("all events")  title("National-level Country Interactions-Syria and Iraq") 
asdoc test covid19eradeathlag_egypt egypt covid19eradeath_lag, append save(1.OTHRCNTYIX_tests.doc) title(Model 2 Wald Test)
asdoc margins, at(covid19eradeathlag_egypt=0 covid19eradeath_lag=0 iraq=0 egypt=1), append save(1.OTHRCNTYIX_tests.doc) title(Model 2 Marginal Effects)
asdoc margins, at(covid19eradeathlag_egypt=1 covid19eradeath_lag=1 iraq=0 egypt=1), append save(1.OTHRCNTYIX_tests.doc) title(Model 2 Marginal Effects)


**A4. MODELS OF LONGEVITY MEASURE OF COVID-19 PANDEMIC*

*Model 1 (All Countries-Egypt, Iraq, Syria) 
xtnbreg isisandlikely_wk covid19weeks vsisis_wklag oilprice_lag ramadan iraq egypt, re
outreg2 using 2.COVIDWKS.doc, replace e(ll) 2aster bdec(2) sdec(2) bfmt(f) ctitle("all events")  title("Longevity Measure of COVID19 Pandemic") 
 
*Model 2 (Iraq Interaction)
gen covid19weeks_iraq = covid19weeks*iraq
xtnbreg isisandlikely_wk covid19weeks covid19weeks_iraq  vsisis_wklag oilprice_lag ramadan iraq egypt, re
outreg2 using 2.COVIDWKS.doc, append e(ll) 2aster bdec(2) sdec(2) bfmt(f) ctitle("all events")  title("Longevity Measure of COVID19 Pandemic") 
asdoc test covid19weeks_iraq covid19weeks iraq, replace save(2.COVIDWKS_tests.doc) title(Model 2 Wald Test)
asdoc margins, at(covid19weeks_iraq=0 covid19weeks=0 iraq=1 egypt=0), append save(2.COVIDWKS_tests.doc) title(Model 2 Marginal Effects)
asdoc margins, at(covid19weeks_iraq=10 covid19weeks=10 iraq=1 egypt=0), append save(2.COVIDWKS_tests.doc) title(Model 2 Marginal Effects)

*Model 3 (Egypt Interaction) 
gen covid19weeks_egypt = covid19weeks*egypt
xtnbreg isisandlikely_wk covid19weeks covid19weeks_egypt  vsisis_wklag oilprice_lag ramadan iraq egypt, re
outreg2 using 2.COVIDWKS.doc, append e(ll) 2aster bdec(2) sdec(2) bfmt(f) ctitle("all events")  title("Longevity Measure of COVID19 Pandemic") 
asdoc test covid19weeks_egypt covid19weeks egypt, append save(2.COVIDWKS_tests.doc) title(Model 3 Wald Test)
asdoc margins, at(covid19weeks_egypt=0 covid19weeks=0 iraq=0 egypt=1), append save(2.COVIDWKS_tests.doc) title(Model 3 Marginal Effects)
asdoc margins, at(covid19weeks_egypt=10 covid19weeks=10 iraq=0 egypt=1), append save(2.COVIDWKS_tests.doc) title(Model 3 Marginal Effects)

*Model 4 (Syria Interaction) 
gen covid19weeks_syria = covid19weeks*syria
xtnbreg isisandlikely_wk covid19weeks covid19weeks_syria  vsisis_wklag oilprice_lag ramadan iraq syria, re
outreg2 using 2.COVIDWKS.doc, append e(ll) 2aster bdec(2) sdec(2) bfmt(f) ctitle("all events")  title("Longevity Measure of COVID19 Pandemic") 
asdoc  test covid19weeks_syria covid19weeks syria, append save(2.COVIDWKS_tests.doc) title(Model 4 Wald Test)
asdoc margins, at(covid19weeks_syria=0 covid19weeks=0 iraq=0 syria=1), append save(2.COVIDWKS_tests.doc) title(Model 4 Marginal Effects)
asdoc margins, at(covid19weeks_syria=10 covid19weeks=10 iraq=0 syria=1), append save(2.COVIDWKS_tests.doc) title(Model 4 Marginal Effects)


** A5. ALTERNATIVE MEASURES ANTI-ISIS VIOLENT EVENTS (2, 3 AND 4 AVG.YEAR LAGS)**
gen oilpricelag_iraq = oilprice_lag*iraq
xtnbreg isisandlikely_wk covid19eradeath_lag vsisis_wklag oilprice_lag oilpricelag_iraq ramadan iraq egypt, re
outreg2 using 3.Altvsisis.doc, replace e(ll) 2aster bdec(2) sdec(2) bfmt(f) ctitle("all events")  title("Anti-ISIS Violent Events Alternative Lags") 

xtnbreg isisandlikely_wk covid19eradeath_lag vsisis_2wklagavg oilprice_lag oilpricelag_iraq ramadan iraq egypt, re
outreg2 using 3.Altvsisis.doc, append e(ll) 2aster bdec(2) sdec(2) bfmt(f) ctitle("all events")  title("Anti-ISIS Violent Events Alternative Lags") 

xtnbreg isisandlikely_wk covid19eradeath_lag vsisis_3wklagavg oilprice_lag oilpricelag_iraq ramadan iraq egypt, re
outreg2 using 3.Altvsisis.doc, append e(ll) 2aster bdec(2) sdec(2) bfmt(f) ctitle("all events")  title("Anti-ISIS Violent Events Alternative Lags") 

xtnbreg isisandlikely_wk covid19eradeath_lag vsisis_4wklagavg oilprice_lag oilpricelag_iraq ramadan iraq egypt, re
outreg2 using 3.Altvsisis.doc, append e(ll) 2aster bdec(2) sdec(2) bfmt(f) ctitle("all events")  title("Anti-ISIS Violent Events Alternative Lags") 


** A6. ADDITION OF US COVID VARIABLES CONTROL**
gen oilpricelag_iraq = oilprice_lag*iraq
xtnbreg isisandlikely_wk covid19eradeath_lag uscovid19eradeath_lag vsisis_wklag oilprice_lag oilpricelag_iraq ramadan iraq egypt, re
outreg2 using 4.USCOVID.doc, replace e(ll) 2aster bdec(2) sdec(2) bfmt(f) ctitle("all events")  title("US COVID Indicators") 

xtnbreg isisandlikely_wk covid19eradeath_lag uscovidcumdeathcdc_lag vsisis_wklag oilprice_lag oilpricelag_iraq ramadan iraq egypt, re
outreg2 using 4.USCOVID.doc, append e(ll) 2aster bdec(2) sdec(2) bfmt(f) ctitle("all events")  title("US COVID Indicators") 

xtnbreg isisandlikelyfatal_wk covid19eradeath_lag uscovidcumdeathcdc_lag covid19eradeathlag_iraq vsisis_wklag oilprice_lag ramadan iraq egypt, re
outreg2 using 4.USCOVID.doc, append e(ll) 2aster bdec(2) sdec(2) bfmt(f) ctitle("all events")  title("US COVID Indicators") 


 
**A7. ISIS PLUS POTENTIAL ISIS INITIATED VIOLENT EVENTS (includes ISIS, ISIS-LIKELY, AND UNCLEAR IF ISIS INITIATOR OR NOT) 

gen isis_likely_unclear_wk =  isisandlikely_wk + isisunclear_wk

*Model 1, DV: Plus Unclear. IV: First Reported COVID-19 Death 
gen oilpricelag_iraq = oilprice_lag*iraq
xtnbreg isis_likely_unclear_wk  covid19eradeath_lag vsisis_wklag oilprice_lag oilpricelag_iraq ramadan iraq egypt, re
outreg2 using 5.UNCLEAR.doc, replace e(ll) 2aster bdec(2) sdec(2) bfmt(f) ctitle("all events")  title("ISIS Plus Potential ISIS-initiated Violent Events (includes ISIS, ISIS-likely & Initiator Unclear") 

*Model 2, DV: Plus Unclear. IV: Cummulative Number of COVID-19 Deaths
xtnbreg isis_likely_unclear_wk  covidcumdeathswho_lag vsisis_wklag oilprice_lag oilpricelag_iraq ramadan iraq egypt, re
outreg2 using 5.UNCLEAR.doc, append e(ll) 2aster bdec(2) sdec(2) bfmt(f) ctitle("all events")  title("ISIS Plus Potential ISIS-initiated Violent Events (includes ISIS, ISIS-likely & Initiator Unclear") 

*Model 3, DV: Plus Unclear. IV: First Reported COVID-19 Death [interaction Iraq] 
gen covid19eradeathlag_iraq = covid19eradeath_lag*iraq
xtnbreg isis_likely_unclear_wk  covid19eradeath_lag covid19eradeathlag_iraq  vsisis_wklag oilprice_lag ramadan iraq egypt, re
outreg2 using 5.UNCLEAR.doc, append e(ll) 2aster bdec(2) sdec(2) bfmt(f) ctitle("all events")  title("ISIS Plus Potential ISIS-initiated Violent Events (includes ISIS, ISIS-likely & Initiator Unclear")  
asdoc test covid19eradeathlag_iraq iraq covid19eradeath_lag, append save(5.UNCLEAR_tests.doc) title(Model 3 Wald Test)
asdoc margins, at(covid19eradeathlag_iraq=0 covid19eradeath_lag=0 iraq=1 egypt=0), append save(5.UNCLEAR_tests.doc) title(Model 3 Marginal Effects)
asdoc margins, at(covid19eradeathlag_iraq=1 covid19eradeath_lag=1 iraq=1 egypt=0), append save(5.UNCLEAR_tests.doc) title(Model 3 Marginal Effects)


*Model 4, DV: Plus Unclear. IV: Cummulative Number of COVID-19 Deaths [interaction Iraq] 
gen covidcumdeathswholag_iraq = covidcumdeathswho_lag*iraq 
xtnbreg isis_likely_unclear_wk  covidcumdeathswho_lag covidcumdeathswholag_iraq  vsisis_wklag oilprice_lag ramadan iraq egypt, re
outreg2 using 5.UNCLEAR.doc, append e(ll) 2aster bdec(2) sdec(2) bfmt(f) ctitle("all events")  title("ISIS Plus Potential ISIS-initiated Violent Events (includes ISIS, ISIS-likely & Initiator Unclear")  
asdoc test covidcumdeathswholag_iraq iraq covidcumdeathswho_lag, append save(5.UNCLEAR_tests.doc) title(Model 4 Wald Test)
asdoc margins, at(covidcumdeathswholag_iraq=0 covidcumdeathswho_lag=0 iraq=1 egypt=0), append save(5.UNCLEAR_tests.doc) title(Model 4 Marginal Effects)
asdoc margins, at(covidcumdeathswholag_iraq=100 covidcumdeathswho_lag=100 iraq=1 egypt=0), append save(5.UNCLEAR_tests.doc) title(Model 4 Marginal Effects)


**A8. ISIS and ISIS LIKELY PLUS UKNOWN ACTOR VS. CIVILIANS 

gen isis_likely_unknown = isisandlikely_wk + unknownactor_wk

*Model 1, DV: Plus Unknown Actor vs. Civilians. IV: First Reported COVID-19 Death 
gen oilpricelag_iraq = oilprice_lag*iraq
xtnbreg isis_likely_unknown covid19eradeath_lag  vsisis_wklag oilprice_lag oilpricelag_iraq ramadan iraq egypt, re
outreg2 using 6.UNKNOWN.doc, replace e(ll) 2aster bdec(2) sdec(2) bfmt(f) ctitle("all events")  title("ISIS Plus Potential ISIS-initiated Violent Events (includes ISIS, ISIS-likely, & Initiator Unknown")  

*Model 2, DV: Plus Unknown Actor vs. Civilians. IV: Cummulative Number of COVID-19 Deaths
xtnbreg isis_likely_unknown covidcumdeathswho_lag  vsisis_wklag oilprice_lag oilpricelag_iraq ramadan iraq egypt, re
outreg2 using 6.UNKNOWN.doc, append e(ll) 2aster bdec(2) sdec(2) bfmt(f) ctitle("all events")  title("ISIS Plus Potential ISIS-initiated Violent Events (includes ISIS, ISIS-likely, & Initiator Unknown")  

*Model 3, DV: Plus Unknown Actor vs. Civilians. IV: First Reported COVID-19 Death [interaction Iraq] 
gen covid19eradeathlag_iraq = covid19eradeath_lag*iraq
xtnbreg isis_likely_unknown covid19eradeath_lag covid19eradeathlag_iraq  vsisis_wklag oilprice_lag ramadan iraq egypt, re
outreg2 using 6.UNKNOWN.doc, append e(ll) 2aster bdec(2) sdec(2) bfmt(f) ctitle("all events")  title("ISIS Plus Potential ISIS-initiated Violent Events (includes ISIS, ISIS-likely, & Initiator Unknown")  
asdoc test covid19eradeathlag_iraq iraq covid19eradeath_lag, append save(6.UNKNOWN_tests.doc) title(Model 3 Wald Test)
asdoc margins, at(covid19eradeathlag_iraq=0 covid19eradeath_lag=0 iraq=1 egypt=0), append save(6.UNKNOWN_tests.doc) title(Model 3 Marginal Effects)
asdoc margins, at(covid19eradeathlag_iraq=1 covid19eradeath_lag=1 iraq=1 egypt=0), append save(6.UNKNOWN_tests.doc) title(Model 3 Marginal Effects)

*Model 4, DV: Plus Unknown Actor vs. Civilians. IV: Cummulative Number of COVID-19 Deaths [interaction Iraq] 
gen covidcumdeathswholag_iraq = covidcumdeathswho_lag*iraq 
xtnbreg isis_likely_unknown covidcumdeathswho_lag covidcumdeathswholag_iraq  vsisis_wklag oilprice_lag ramadan iraq egypt, re
outreg2 using 6.UNKNOWN.doc, append e(ll) 2aster bdec(2) sdec(2) bfmt(f) ctitle("all events")  title("ISIS Plus Potential ISIS-initiated Violent Events (includes ISIS, ISIS-likely, & Initiator Unknown")  
asdoc test covidcumdeathswholag_iraq iraq covidcumdeathswho_lag, append save(6.UNKNOWN_tests.doc) title(Model 4 Wald Test)
asdoc margins, at(covidcumdeathswholag_iraq=0 covidcumdeathswho_lag=0 iraq=1 egypt=0), append save(6.UNKNOWN_tests.doc) title(Model 4 Marginal Effects)
asdoc margins, at(covidcumdeathswholag_iraq=100 covidcumdeathswho_lag=100 iraq=1 egypt=0), append save(6.UNKNOWN_tests.doc) title(Model 4 Marginal Effects)


*A9. NATIONAL LEVEL ANALYSIS OF CURFEWS AND BANS**

*Model 1: Curfews
bysort iso: gen ISIScurfewsdi_lag = ISIScurfewsdi[_n-1]
xtnbreg isisandlikely_wk covid19eradeath_lag vsisis_wklag oilprice_lag nonISIScurfewsdi_lag ISIScurfewsdi_lag ramadan iraq egypt, re
outreg2 using 7.NATLlockdowns.doc, replace e(ll) 2aster bdec(2) sdec(2) bfmt(f) ctitle("all events")  title("National-level Analysis of Lockdowns")  
asdoc test nonISIScurfewsdi_lag ISIScurfewsdi_lag,  append save(7.NATLlockdowns_tests.doc) title(Model 1 Wald Test)

*Model 2: Curfews and Iraq Interaction
gen covid19eradeath_lag_iraq = covid19eradeath_lag*iraq
xtnbreg isisandlikely_wk covid19eradeath_lag covid19eradeath_lag_iraq vsisis_wklag oilprice_lag nonISIScurfewsdi_lag ISIScurfewsdi_lag ramadan iraq egypt, re
outreg2 using 7.NATLlockdowns.doc, append  e(ll) 2aster bdec(2) sdec(2) bfmt(f) ctitle("all events")  title("National-level Analysis of Lockdowns")  
asdoc test covid19eradeath_lag iraq covid19eradeath_lag_iraq,  append save(7.NATLlockdowns_tests.doc) title(Model 2 Wald Test)

*Model 3: Travel Bans
browse internalbansdi nonISISnternalbansdi
gen ISISinternalbansdi = 1 if (internalbansdi == 1 & nonISISnternalbansdi == 0)
recode ISISinternalbansdi . = 0 if internalbansdi != .
bysort iso: gen ISISinternalbansdi_lag = ISISinternalbansdi[_n-1]

xtnbreg isisandlikely_wk covid19eradeath_lag vsisis_wklag oilprice_lag nonISISnternalbansdi_lag ISISinternalbansdi_lag ramadan iraq egypt, re
outreg2 using 7.NATLlockdowns.doc, append e(ll) 2aster bdec(2) sdec(2) bfmt(f) ctitle("all events")  title("National-level Analysis of Lockdowns")  
asdoc test covid19eradeath_lag iraq covid19eradeath_lag_iraq,  append save(7.NATLlockdowns_tests.doc) title(Model 3 Wald Test)

*Model 4: Travel Bans and Iraq Interaction
xtnbreg isisandlikely_wk covid19eradeath_lag covid19eradeath_lag_iraq vsisis_wklag oilprice_lag nonISISnternalbansdi_lag ISISinternalbansdi_lag ramadan iraq egypt, re
outreg2 using 7.NATLlockdowns.doc, append e(ll) 2aster bdec(2) sdec(2) bfmt(f) ctitle("all events")  title("National-level Analysis of Lockdowns")  
asdoc test covid19eradeath_lag iraq covid19eradeath_lag_iraq, append save(7.NATLlockdowns_tests.doc) title(Model 4 Wald Test)



*************************************************************************************************************
*************************************************************************************************************
****************************************** II. GOVERNORATE-LEVEL ANALYSIS  **********************************
*************************************************************************************************************
************************************************************************************************************* 

clear
use "/LDV_GOVLEVEL.dta"

*Time-Set the Data
gen isogovadmcode = govadmcode + 100 if country == "Republic of Iraq"
replace isogovadmcode = govadmcode + 1000 if country == "Arab Republic of Egypt"
replace isogovadmcode = govadmcode + 100000 if country == "Syrian Arab Republic"

xtset isogovadmcode week

*Generate Country Indicators* 
gen syria  = 0 
replace syria = 1 if iso == 760 
gen iraq = 0 
replace iraq = 1 if iso  == 368
gen egypt = 0 
replace egypt = 1 if iso  == 818

*generate lags*
sort iso week 
foreach  variable of varlist  ramadan covid19eracase covid19eradeath oilprice uscovid19eradeath uscovidcumdeathcdc uscovidcumdeathdatecdc uscovidcumdeathswho internalbanstri curfewsdi curfewstri covidcumdeathswho covidcumdeathsdatewho usforces iranforces sdfforces gosforces goiforces pmfforces goeforces securityaidtotal economicaidusaid humanitarianaidunfts covidaidunfts covidaidstate internalbansdi ISIScurfewsdi nonISIScurfewsdi nonISISnternalbansdi nonISISneighbansdi {
bysort iso: gen `variable'_lag = `variable'[_n-1]
}
destring, replace

gen base = 1 if (governorate == "North Sinai" | governorate == "Diyala" | governorate == "Deir Ez-Zor")
recode base . = 0 	

************************************************************* ANALYSIS ********************************************************************** 


** A1. Location of Lockdown Measures 
sort country year week governorate 
browse country year week governorate ISIScurfewsdi nonISIScurfewsdi if (ISIScurfewsdi != 0 | nonISIScurfewsdi !=0 ) & (ISIScurfewsdi != . | nonISIScurfewsdi !=.)
asdoc list country year week governorate ISIScurfewsdi nonISIScurfewsdi if (ISIScurfewsdi != 0 | nonISIScurfewsdi !=0 ) & (ISIScurfewsdi != . | nonISIScurfewsdi !=.), replace save(1.LockdownsList.doc) title(Lockdown Measures List)
 
browse country year week governorate ISISinternalbansdi nonISISinternalbansdi if (ISIScurfewsdi != 0 | nonISIScurfewsdi !=0 ) & (ISIScurfewsdi != . | nonISIScurfewsdi !=.)
asdoc list country year week governorate ISISinternalbansdi nonISISinternalbansdi if (ISISinternalbansdi  != 0 | nonISISinternalbansdi !=0 ) & (ISISinternalbansdi != . | nonISISinternalbansdi !=.), append save(1.LockdownsList.doc) title(Lockdown Measures List)


* A10: Article Table 2: Marginal Effects

*Model 6, DV: ISIS-initiated Violent Events (includes likely). IV: COVID-19 Era  (Curfews) 
xtnbreg isisandlikely_wk covid19eradeath_lag vsisis_wk_lag oilprice_lag nonISIScurfewsdi_lag ISIScurfewsdi_lag ramadan iraq egypt, re
asdoc margins, at(nonISIScurfewsdi_lag=0 ISIScurfewsdi_lag=0), append save(T2.Margins.doc) title(Table 2 Marginal Effects)
asdoc margins, at(nonISIScurfewsdi_lag=1 ISIScurfewsdi_lag=0), append save(T2.Margins.doc) title(Table 2 Marginal Effects)
asdoc margins, at(nonISIScurfewsdi_lag=0 ISIScurfewsdi_lag=1), append save(T2.Margins.doc) title(Table 2 Marginal Effects)

xtnbreg isisandlikely_wk vsisis_wk_lag oilprice_lag nonISIScurfewsdi_lag ISIScurfewsdi_lag ramadan iraq egypt, re
asdoc margins, at(nonISIScurfewsdi_lag=0 ISIScurfewsdi_lag=0), append save(T2.Margins.doc) title(Table 2 Marginal Effects)
asdoc margins, at(nonISIScurfewsdi_lag=1 ISIScurfewsdi_lag=0), append save(T2.Margins.doc) title(Table 2 Marginal Effects)
asdoc margins, at(nonISIScurfewsdi_lag=0 ISIScurfewsdi_lag=1), append save(T2.Margins.doc) title(Table 2 Marginal Effects)

*Model 7, DV: ISIS-initiated Violent Events (includes likely). IV: COVID-19 Era  (Curfews) [and Interaction population]
gen nonISIScurfewsdi_pop = nonISIScurfewsdi_lag*population
gen ISIScurfewsdi_pop = ISIScurfewsdi_lag*population
xtnbreg isisandlikely_wk covid19eradeath_lag vsisis_wk_lag oilprice_lag nonISIScurfewsdi_lag nonISIScurfewsdi_pop ISIScurfewsdi_pop ISIScurfewsdi_lag 	 ramadan iraq egypt, re
asdoc margins, at(nonISIScurfewsdi_pop=0 nonISIScurfewsdi_lag=0 population=1500000 ISIScurfewsdi_lag=0 ISIScurfewsdi_pop=0), append save(T2.Margins.doc) title(Table 2 Marginal Effects) 
asdoc margins, at(nonISIScurfewsdi_pop=0 nonISIScurfewsdi_lag=0 population=8500000 ISIScurfewsdi_lag=0 ISIScurfewsdi_pop=0), append save(T2.Margins.doc) title(Table 2 Marginal Effects)
asdoc margins, at(nonISIScurfewsdi_pop=1500000 nonISIScurfewsdi_lag=1 population=1500000  ISIScurfewsdi_lag=0 ISIScurfewsdi_pop=0), append save(T2.Margins.doc) title(Table 2 Marginal Effects)
asdoc margins, at(nonISIScurfewsdi_pop=8500000 nonISIScurfewsdi_lag=1 population=8500000 ISIScurfewsdi_lag=0 ISIScurfewsdi_pop=0), append save(T2.Margins.doc) title(Table 2 Marginal Effects)

xtnbreg isisandlikely_wk  vsisis_wk_lag oilprice_lag nonISIScurfewsdi_lag nonISIScurfewsdi_pop ISIScurfewsdi_pop ISIScurfewsdi_lag population ramadan iraq egypt, re
asdoc margins, at(nonISIScurfewsdi_pop=0 nonISIScurfewsdi_lag=0 population=1500000 ISIScurfewsdi_lag=0 ISIScurfewsdi_pop=0), append save(T2.Margins.doc) title(Table 2 Marginal Effects) 
asdoc margins, at(nonISIScurfewsdi_pop=0 nonISIScurfewsdi_lag=0 population=8500000 ISIScurfewsdi_lag=0 ISIScurfewsdi_pop=0), append save(T2.Margins.doc) title(Table 2 Marginal Effects)
asdoc margins, at(nonISIScurfewsdi_pop=1500000 nonISIScurfewsdi_lag=1 population=1500000  ISIScurfewsdi_lag=0 ISIScurfewsdi_pop=0), append save(T2.Margins.doc) title(Table 2 Marginal Effects)
asdoc margins, at(nonISIScurfewsdi_pop=8500000 nonISIScurfewsdi_lag=1 population=8500000 ISIScurfewsdi_lag=0 ISIScurfewsdi_pop=0), append save(T2.Margins.doc) title(Table 2 Marginal Effects)


*Model 8, DV: ISIS-initiated Violent Events (includes likely). IV: COVID-19 Era  (Travel Bans instead of Curfews)
xtnbreg isisandlikely_wk covid19eradeath_lag vsisis_wk_lag oilprice_lag nonISISinternalbansdi_lag ISISinternalbansdi_lag ramadan iraq egypt, re
asdoc margins, at(nonISISinternalbansdi_lag=0 ISISinternalbansdi_lag=0), append save(T2.Margins.doc) title(Table 2 Marginal Effects)
asdoc margins, at(nonISISinternalbansdi_lag=1 ISISinternalbansdi_lag=0), append save(T2.Margins.doc) title(Table 2 Marginal Effects)
asdoc margins, at(nonISISinternalbansdi_lag=0 ISISinternalbansdi_lag=1), append save(T2.Margins.doc) title(Table 2 Marginal Effects)

xtnbreg isisandlikely_wk vsisis_wk_lag oilprice_lag nonISISinternalbansdi_lag ISISinternalbansdi_lag ramadan iraq egypt, re
asdoc margins, at(nonISISinternalbansdi_lag=0 ISISinternalbansdi_lag=0), append save(T2.Margins.doc) title(Table 2 Marginal Effects)
asdoc margins, at(nonISISinternalbansdi_lag=1 ISISinternalbansdi_lag=0), append save(T2.Margins.doc) title(Table 2 Marginal Effects)
asdoc margins, at(nonISISinternalbansdi_lag=0 ISISinternalbansdi_lag=1), append save(T2.Margins.doc) title(Table 2 Marginal Effects)


* Model 9, DV: ISIS-initiated Violent Events (includes likely). IV: COVID-19 Era  (Travel Bans instead of Curfews) [and Interaction base]
gen nonISISinternalbansdi_base = nonISISinternalbansdi_lag*base
gen ISISinternalbansdi_base = ISISinternalbansdi_lag*base
xtnbreg isisandlikely_wk covid19eradeath_lag vsisis_wk_lag oilprice_lag nonISISinternalbansdi_lag ISISinternalbansdi_lag ISISinternalbansdi_base nonISISinternalbansdi_base base ramadan iraq egypt, re
asdoc margins, at(nonISISinternalbansdi_base=0 nonISISinternalbansdi_lag=0 base=0 ISISinternalbansdi_lag=0), append save(T2.Margins.doc) title(Table 2 Marginal Effects)
asdoc margins, at(nonISISinternalbansdi_base=0 nonISISinternalbansdi_lag=0 base=1 ISISinternalbansdi_lag=0), append save(T2.Margins.doc) title(Table 2 Marginal Effects)
asdoc margins, at(nonISISinternalbansdi_base=0 nonISISinternalbansdi_lag=1 base=0 ISISinternalbansdi_lag=0), append save(T2.Margins.doc) title(Table 2 Marginal Effects)
asdoc margins, at(nonISISinternalbansdi_base=1 nonISISinternalbansdi_lag=1 base=1 ISISinternalbansdi_lag=0), append save(T2.Margins.doc) title(Table 2 Marginal Effects)

xtnbreg isisandlikely_wk vsisis_wk_lag oilprice_lag nonISISinternalbansdi_lag ISISinternalbansdi_lag ISISinternalbansdi_base nonISISinternalbansdi_base base ramadan iraq egypt, re
asdoc margins, at(nonISISinternalbansdi_base=0 nonISISinternalbansdi_lag=0 base=0 ISISinternalbansdi_lag=0), append save(T2.Margins.doc) title(Table 2 Marginal Effects)
asdoc margins, at(nonISISinternalbansdi_base=0 nonISISinternalbansdi_lag=0 base=1 ISISinternalbansdi_lag=0), append save(T2.Margins.doc) title(Table 2 Marginal Effects)
asdoc margins, at(nonISISinternalbansdi_base=0 nonISISinternalbansdi_lag=1 base=0 ISISinternalbansdi_lag=0), append save(T2.Margins.doc) title(Table 2 Marginal Effects)
asdoc margins, at(nonISISinternalbansdi_base=1 nonISISinternalbansdi_lag=1 base=1 ISISinternalbansdi_lag=0), append save(T2.Margins.doc) title(Table 2 Marginal Effects)


** A11. GOVERNORATE-LEVEL: COVID ONLY CURFEWS AND BANS **

gen COVIDcurfews = 0 if curfewsdi ! = . 
recode COVIDcurfews 0 = 1 if curfewsdi == 1 & covid19eradeath == 1
sort iso governorate week 
bysort iso governorate: gen COVIDcurfews_lag = COVIDcurfews[_n-1]

gen nonCOVIDcurfews = 0 if curfewsdi ! = .
recode nonCOVIDcurfews 0 = 1 if curfewsdi == 1 & covid19eradeath == 0
recode nonCOVIDcurfews 0 = 1 if governorate == "North Sinai"
bysort iso governorate: gen nonCOVIDcurfews_lag = nonCOVIDcurfews[_n-1]
 *Northern Sinai is coded as nonCOVID because they predated the pandemic**

**Model 1: COVID-19 Curfews
xtnbreg isisandlikely_wk vsisis_wk_lag COVIDcurfews_lag nonCOVIDcurfews_lag oilprice_lag ramadan iraq syria, re
outreg2 using 2.COVID19onlyLockdowns.doc, replace e(ll) 2aster bdec(2) sdec(2) bfmt(f) ctitle("all events")  title("COVID-19 Only Lockdowns")
asdoc test COVIDcurfews_lag nonCOVIDcurfews, append save(2.COVID19onlyLockdowns_test.doc) title(Model 1 Wald Test)

**Model 2: COVID-19 Curfews and Population Interaction
gen nonCOVIDcurfewslag_population = nonCOVIDcurfews_lag*population 
gen COVIDcurfewslag_population = COVIDcurfews_lag*population 

xtnbreg isisandlikely_wk vsisis_wk_lag COVIDcurfews_lag nonCOVIDcurfews_lag COVIDcurfewslag_population population oilprice_lag ramadan iraq syria, re
outreg2 using 2.COVID19onlyLockdowns.doc, append e(ll) 2aster bdec(2) sdec(2) bfmt(f) ctitle("all events")  title("COVID-19 Only Lockdowns")
asdoc test COVIDcurfewslag_population nonCOVIDcurfews_lag population, append save(2.COVID19onlyLockdowns_test.doc) title(Model 2 Wald Test)
asdoc margins, at(COVIDcurfewslag_population=100000  nonCOVIDcurfews_lag=0 population=100000), append save(2.COVID19onlyLockdowns_test.doc) title(Model 2 Marginal Effects)
asdoc margins, at(COVIDcurfewslag_population=1000000 nonCOVIDcurfews_lag=0 population=1000000), append save(2.COVID19onlyLockdowns_test.doc) title(Model 2 Marginal Effects)

**Model 3: COVID-19 COVID Travel Bans**
gen COVIDinternalbansdi = 0 if internalbansdi ! = . 
recode COVIDinternalbansdi 0 = 1 if internalbansdi == 1 & covid19eradeath == 1
bysort iso: gen COVIDinternalbansdi_lag = COVIDinternalbansdi[_n-1]

* Northern Sinai is coded as nonCOVID because restrictions predated the pandemic**
gen nonCOVIDinternalbansdi = 0 if internalbansdi ! = .
recode nonCOVIDinternalbansdi 0 = 1 if internalbansdi == 1 & covid19eradeath == 0
recode nonCOVIDinternalbansdi 1 = 0 if governorate == "North Sinai"
bysort iso: gen nonCOVIDinternalbansdi_lag = nonCOVIDinternalbansdi[_n-1]

xtnbreg isisandlikely_wk vsisis_wk_lag COVIDinternalbansdi_lag nonCOVIDinternalbansdi oilprice_lag ramadan iraq syria, re
outreg2 using 2.COVID19onlyLockdowns.doc, append e(ll) 2aster bdec(2) sdec(2) bfmt(f) ctitle("all events")  title("COVID-19 Only Lockdowns")
asdoc test COVIDinternalbansdi_lag nonCOVIDinternalbansdi, append save(2.COVID19onlyLockdowns_test.doc) title(Model 3 Wald Test)

**Model 4: COVID-19 COVID Travel Bans and Base Areas**
gen COVIDinternalbansdilag_base = COVIDinternalbansdi_lag*base 
xtnbreg isisandlikely_wk vsisis_wk_lag COVIDinternalbansdi_lag nonCOVIDinternalbansdi_lag COVIDinternalbansdilag_base base oilprice_lag ramadan iraq syria, re
outreg2 using 2.COVID19onlyLockdowns.doc, append e(ll) 2aster bdec(2) sdec(2) bfmt(f) ctitle("all events")  title("COVID-19 Only Lockdowns")
asdoc test COVIDinternalbansdilag_base COVIDinternalbansdi_lag base, append save(2.COVID19onlyLockdowns_test.doc) title(Model 4 Wald Test)



** A12. ZERO-INFLATION MODELS, USING POPULATION TO INFLATE **

*Model 1*
zinb isisandlikely_wk covid19eradeath_lag vsisis_wk_lag oilprice_lag nonISIScurfewsdi_lag ISIScurfewsdi_lag ramadan iraq egypt, inflate (population) 
outreg2 using 3.ZINB.doc, replace e(ll) 2aster bdec(2) sdec(2) bfmt(f) ctitle("all events")  title("Zero-Inflation Negative Binomial Models")  addnote("In all models, population is used as the inflation factor. Model 1:  Results indiciate that non-ISIS curfews increase violent events over no curfews, but the model fit not as good as negative binomial models.")
asdoc test nonISIScurfewsdi_lag ISIScurfewsdi_lag, append save(3.ZINB_test.doc) title(Model 1 Wald Test)

*Model 2*
gen nonISIScurfewsdi_pop = nonISIScurfewsdi*population
zinb isisandlikely_wk covid19eradeath_lag vsisis_wk_lag oilprice_lag nonISIScurfewsdi_lag nonISIScurfewsdi_pop ISIScurfewsdi_lag population ramadan iraq egypt, inflate (population) 
outreg2 using 3.ZINB.doc, append e(ll) 2aster bdec(2) sdec(2) bfmt(f) ctitle("all events")  title("Zero-Inflation Negative Binomial Models") 
asdoc test nonISIScurfewsdi_pop nonISIScurfewsdi_lag population, append save(3.ZINB_test.doc) title(Model 2 Wald Test) 
asdoc margins, at(nonISIScurfewsdi_pop=100000  nonISIScurfewsdi_lag=1 population=100000), append save(3.ZINB_test.doc) title(Model 2 Marginal Effects)
asdoc margins, at(nonISIScurfewsdi_pop=1000000 nonISIScurfewsdi_lag=1 population=1000000), append save(3.ZINB_test.doc) title(Model 2 Marginal Effects)

*Model 3*
zinb isisandlikely_wk covid19eradeath_lag vsisis_wk_lag oilprice_lag nonISISinternalbansdi_lag ISISinternalbansdi_lag ramadan iraq egypt, inflate (population)
outreg2 using 3.ZINB.doc, append e(ll) 2aster bdec(2) sdec(2) bfmt(f) ctitle("all events")  title("Zero-Inflation Negative Binomial Models")  addnote("Model 3 fit not as good as negative binomial models.")
asdoc test nonISISinternalbansdi_lag ISISinternalbansdi_lag, append save(3.ZINB_test.doc) title(Model 3 Wald Test)

*Model 4*
gen nonISISinternalbansdi_base = nonISISinternalbansdi_lag*base
gen ISISinternalbansdi_base = ISISinternalbansdi_lag*base
zinb isisandlikely_wk covid19eradeath_lag vsisis_wk_lag oilprice_lag nonISISinternalbansdi_lag ISISinternalbansdi_lag ISISinternalbansdi_base nonISISinternalbansdi_base base ramadan iraq egypt, inflate (population)
outreg2 using 3.ZINB.doc, append e(ll) 2aster bdec(2) sdec(2) bfmt(f) ctitle("all events")  title("Zero-Inflation Negative Binomial Models") 
asdoc test nonISISinternalbansdi_base base nonISISinternalbansdi_lag, append save(3.ZINB_test.doc) title(Model 4 Wald Test)
asdoc test nonISISinternalbansdi_base nonISISinternalbansdi_lag base ISISinternalbansdi_lag ISISinternalbansdi_base, append save(3.ZINB_test.doc) title(Model 4 Wald Test)



** A13. EEFFECT OF LOCKDOWNS WITHOUT PANDEMIC**

*Model 1
xtnbreg isisandlikely_wk vsisis_wk_lag oilprice_lag ISIScurfewsdi_lag nonISIScurfewsdi_lag ramadan iraq egypt, re
outreg2 using 4.NOPANDEMIC.doc, replace e(ll) 2aster bdec(2) sdec(2) bfmt(f) ctitle("all events")  title("Effect of Lockdowns without Pandemic") 
asdoc test ISIScurfewsdi_lag nonISIScurfewsdi_lag, append save(4.NOPANDEMIC_test.doc) title(Model 1 Wald Test)

*Model 2

xtnbreg isisandlikely_wk vsisis_wk_lag oilprice_lag ISISinternalbansdi_lag nonISISinternalbansdi_lag ramadan iraq egypt, re
outreg2 using 4.NOPANDEMIC.doc, append e(ll) 2aster bdec(2) sdec(2) bfmt(f) ctitle("all events")  title("Effect of Lockdowns without Pandemic") 
asdoc test ISISinternalbansdi_lag nonISISinternalbansdi_lag, append save(4.NOPANDEMIC_test.doc) title(Model 2 Wald Test)



** A14. IRAQ INTERACTION WITH PANDEMIC AT THE GOVERNORATE LEVEL WITH AND OUT NO CURFEWS**

*Model 1
gen covid19eradeathlag_iraq = covid19eradeath_lag*iraq
xtnbreg isisandlikely_wk covid19eradeath_lag covid19eradeathlag_iraq vsisis_wk_lag oilprice_lag ramadan iraq egypt, re
outreg2 using 5.IRAQITNgov.doc, replace e(ll) 2aster bdec(2) sdec(2) bfmt(f) ctitle("all events")  title("Iraq Interaction with Pandemic at Governorate Level") 
asdoc test covid19eradeathlag_iraq  covid19eradeath_lag iraq, append save(5.IRAQITNgov_test.doc) title(Model 1 Wald Test)
asdoc margins, at(covid19eradeathlag_iraq=0 covid19eradeath_lag=0 iraq=1 egypt=0), append save(5.IRAQITNgov_test.doc) title(Model 1 Marginal Effects)
asdoc margins, at(covid19eradeathlag_iraq=1 covid19eradeath_lag=1 iraq=1 egypt=0), append save(5.IRAQITNgov_test.doc) title(Model 1 Marginal Effects)

*Model 2
xtnbreg isisandlikely_wk covid19eradeath_lag covid19eradeathlag_iraq vsisis_wk_lag oilprice_lag ISIScurfewsdi_lag nonISIScurfewsdi_lag ramadan iraq egypt, re
outreg2 using 5.IRAQITNgov.doc, append e(ll) 2aster bdec(2) sdec(2) bfmt(f) ctitle("all events")  title("Iraq Interaction with Pandemic at Governorate Level") 
asdoc test covid19eradeathlag_iraq  covid19eradeath_lag iraq, append save(5.IRAQITNgov_test.doc) title(Model 2 Wald Test)
asdoc margins, at(covid19eradeathlag_iraq=0 covid19eradeath_lag=0 iraq=1 egypt=0), append save(5.IRAQITNgov_test.doc) title(Model 2 Marginal Effects)
asdoc margins, at(covid19eradeathlag_iraq=1 covid19eradeath_lag=1 iraq=1 egypt=0), append save(5.IRAQITNgov_test.doc) title(Model 2 Marginal Effects)



** A15. LOCKDOWN RESTRICTED TO COUNTRIES INSTEAD OF INTERACTIONS WITH COUNTRIES ** 

*Model 1*
xtnbreg isisandlikely_wk covid19eradeath_lag vsisis_wk_lag oilprice_lag nonISIScurfewsdi_lag ISIScurfewsdi_lag ramadan if iraq == 1, re
outreg2 using 6.CNTYSUBSET.doc, replace e(ll) 2aster bdec(2) sdec(2) bfmt(f) ctitle("all events (Iraq)")  title("Pandemic- Subsetted by Country")

*Model 2*
xtnbreg isisandlikely_wk covid19eradeath_lag vsisis_wk_lag oilprice_lag nonISIScurfewsdi_lag ISIScurfewsdi_lag ramadan if syria == 1, re
outreg2 using 6.CNTYSUBSET.doc, append e(ll) 2aster bdec(2) sdec(2) bfmt(f) ctitle("all events (Syria)")  title("Pandemic- Subsetted by Country")


** A16. LOCKDOWN INTERACTIONS (CURFEWS) WITH COUNTRIES (IRAQ AND SYRIA) AT GOVERNORATE LEVEL** 

*Model 1*
gen nonISIScurfewsdi_iraq = nonISIScurfewsdi_lag*iraq
gen ISIScurfewsdi_iraq = ISIScurfewsdi*iraq
xtnbreg isisandlikely_wk covid19eradeath_lag vsisis_wk_lag oilprice_lag nonISIScurfewsdi_lag nonISIScurfewsdi_iraq ramadan iraq syria, re
outreg2 using 7.iCNTYgov.doc, replace e(ll) 2aster bdec(2) sdec(2) bfmt(f) ctitle("all events")  title("Curfews-Country Interaction at Governorate Level")
asdoc test nonISIScurfewsdi_iraq nonISIScurfewsdi_lag iraq, append save(7.iCNTYgov_test.doc) title(Model 1 Wald Test)
asdoc margins, at(nonISIScurfewsdi_iraq=0 nonISIScurfewsdi_lag=0 iraq=1 syria=0), append save(7.iCNTYgov_test.doc) title(Model 1 Marginal Effects)
asdoc margins, at(nonISIScurfewsdi_iraq=1 nonISIScurfewsdi_lag=1 iraq=1 syria=0), append save(7.iCNTYgov_test.doc) title(Model 1 Marginal Effects)

*Model 2*
xtnbreg isisandlikely_wk covid19eradeath_lag vsisis_wk_lag oilprice_lag ISIScurfewsdi_iraq ISIScurfewsdi_lag nonISIScurfewsdi_lag nonISIScurfewsdi_iraq ramadan iraq syria, re
outreg2 using 7.iCNTYgov.doc, append e(ll) 2aster bdec(2) sdec(2) bfmt(f) ctitle("all events")  title("Curfews-Country Interaction at Governorate Level")
asdoc test ISIScurfewsdi_lag ISIScurfewsdi_iraq nonISIScurfewsdi_lag nonISIScurfewsdi_iraq iraq, append save(7.iCNTYgov_test.doc) title(Model 2 Wald Test)
asdoc margins, at(ISIScurfewsdi_lag=0 ISIScurfewsdi_iraq=0 nonISIScurfewsdi_lag=0 nonISIScurfewsdi_iraq=0  iraq=1 syria=0), append save(7.iCNTYgov_test.doc) title(Model 2 Marginal Effects)
asdoc margins, at(ISIScurfewsdi_lag=0 ISIScurfewsdi_iraq=0 nonISIScurfewsdi_lag=1 nonISIScurfewsdi_iraq=1  iraq=1 syria=0), append save(7.iCNTYgov_test.doc) title(Model 2 Marginal Effects)
	
*Model 3*
gen nonISIScurfewsdi_syria = nonISIScurfewsdi_lag*syria
gen ISIScurfewsdi_syria = ISIScurfewsdi_lag*syria
xtnbreg isisandlikely_wk covid19eradeath_lag vsisis_wk_lag oilprice_lag ISIScurfewsdi_lag nonISIScurfewsdi_lag nonISIScurfewsdi_syria ramadan iraq syria, re
outreg2 using 7.iCNTYgov.doc, append e(ll) 2aster bdec(2) sdec(2) bfmt(f) ctitle("all events")  title("Curfews-Country Interaction at Governorate Level")
asdoc test nonISIScurfewsdi_syria nonISIScurfewsdi_lag syria, append save(7.iCNTYgov_test.doc) title(Model 3 Wald Test)
asdoc margins, at(nonISIScurfewsdi_syria=0 nonISIScurfewsdi_lag=0 iraq=0 syria=1), append save(7.iCNTYgov_test.doc) title(Model 3 Marginal Effects)
asdoc margins, at(nonISIScurfewsdi_syria=1 nonISIScurfewsdi_lag=1 iraq=0 syria=1), append save(7.iCNTYgov_test.doc) title(Model 3 Marginal Effects)

**Model 4**
xtnbreg isisandlikely_wk covid19eradeath_lag vsisis_wk_lag oilprice_lag ISIScurfewsdi_syria ISIScurfewsdi_lag nonISIScurfewsdi_lag nonISIScurfewsdi_syria ramadan iraq syria, re
outreg2 using 7.iCNTYgov.doc, append e(ll) 2aster bdec(2) sdec(2) bfmt(f) ctitle("all events")  title("Curfews-Country Interaction at Governorate Level")
asdoc test ISIScurfewsdi_syria ISIScurfewsdi_lag nonISIScurfewsdi_lag nonISIScurfewsdi_syria, append save(7.iCNTYgov_test.doc) title(Model 4 Wald Test)
asdoc margins, at(ISIScurfewsdi_lag=0 ISIScurfewsdi_syria=0 nonISIScurfewsdi_lag=0 nonISIScurfewsdi_syria=0  iraq=0 syria=1), append save(7.iCNTYgov_test.doc) title(Model 4 Marginal Effects)
asdoc margins, at(ISIScurfewsdi_lag=0 ISIScurfewsdi_syria=0 nonISIScurfewsdi_lag=1 nonISIScurfewsdi_syria=1  iraq=0 syria=1), append save(7.iCNTYgov_test.doc) title(Model 4 Marginal Effects)


** A17. LOCKDOWN INTERACTIONS (TRAVEL BANS) WITH COUNTRIES (IRAQ AND SYRIA) AT GOVERNORATE LEVEL** 

*Model 1**
gen nonISISinternalbansdi_lag_iraq = nonISISinternalbansdi_lag*iraq
gen ISISinternalbansdi_lag_iraq = ISISinternalbansdi_lag*iraq
xtnbreg isisandlikely_wk covid19eradeath_lag vsisis_wk_lag oilprice_lag nonISISinternalbansdi_lag nonISISinternalbansdi_lag_iraq ramadan iraq egypt, re
outreg2 using 8.iCNTY2gov.doc, replace e(ll) 2aster bdec(2) sdec(2) bfmt(f) ctitle("all events")  title("Travel Bans-Country Interaction at Governorate Level")
asdoc test nonISISinternalbansdi_lag_iraq iraq nonISISinternalbansdi_lag, append save(8.i2CNTYgov_test.doc) title(Model 1 Wald Test)

*Model 2**
xtnbreg isisandlikely_wk covid19eradeath_lag vsisis_wk_lag oilprice_lag ISISinternalbansdi_lag_iraq ISISinternalbansdi_lag nonISISinternalbansdi_lag nonISISinternalbansdi_lag_iraq ramadan iraq egypt, re
outreg2 using 8.iCNTY2gov.doc, append e(ll) 2aster bdec(2) sdec(2) bfmt(f) ctitle("all events")  title("Travel Bans-Country Interaction at Governorate Level")
asdoc test nonISISinternalbansdi_lag_iraq iraq nonISISinternalbansdi_lag ISISinternalbansdi_lag ISISinternalbansdi_lag_iraq, append save(8.i2CNTYgov_test.doc) title(Model 2 Wald Test)
asdoc margins, at(nonISISinternalbansdi_lag=0  nonISISinternalbansdi_lag_iraq=0 ISISinternalbansdi_lag=0 ISISinternalbansdi_lag_iraq=0 iraq=1 egypt=0), append save(8.i2CNTYgov_test.doc) title(Model 2 Marginal Effects)
asdoc margins, at(nonISISinternalbansdi_lag=1  nonISISinternalbansdi_lag_iraq=1 ISISinternalbansdi_lag=0 ISISinternalbansdi_lag_iraq=0 iraq=1 egypt=0), append save(8.i2CNTYgov_test.doc) title(Model 2 Marginal Effects)

*Model 3**
gen nonISISinternalbansdi_lag_syria = nonISISinternalbansdi_lag*syria
gen ISISinternalbansdi_lag_syria = ISISinternalbansdi_lag*syria
xtnbreg isisandlikely_wk covid19eradeath_lag vsisis_wk_lag oilprice_lag nonISISinternalbansdi_lag nonISISinternalbansdi_lag_syria ramadan iraq syria, re
outreg2 using 8.iCNTY2gov.doc, append e(ll) 2aster bdec(2) sdec(2) bfmt(f) ctitle("all events")  title("Travel Bans-Country Interaction at Governorate Level")
asdoc test nonISISinternalbansdi_lag_syria syria nonISISinternalbansdi_lag, append save(8.i2CNTYgov_test.doc) title(Model 3 Wald Test)

*less effective/increases ISIS-violence
*Model 4*
xtnbreg isisandlikely_wk covid19eradeath_lag vsisis_wk_lag oilprice_lag ISISinternalbansdi_lag nonISISinternalbansdi_lag nonISISinternalbansdi_lag_syria ramadan iraq syria, re
test nonISISinternalbansdi_lag_syria syria nonISISinternalbansdi_lag
xtnbreg isisandlikely_wk covid19eradeath_lag vsisis_wk_lag oilprice_lag ISISinternalbansdi_lag_syria ISISinternalbansdi_lag nonISISinternalbansdi_lag nonISISinternalbansdi_lag_syria ramadan iraq syria, re
outreg2 using 8.iCNTY2gov.doc, append e(ll) 2aster bdec(2) sdec(2) bfmt(f) ctitle("all events")  title("Travel Bans-Country Interaction at Governorate Level")
asdoc test nonISISinternalbansdi_lag_syria syria nonISISinternalbansdi_lag ISISinternalbansdi_lag_syria, append save(8.i2CNTYgov_test.doc) title(Model 4 Wald Test)
asdoc margins, at(nonISISinternalbansdi_lag=0  nonISISinternalbansdi_lag_syria=0 ISISinternalbansdi_lag=0 ISISinternalbansdi_lag_syria=0 syria=1 iraq=0), append save(8.i2CNTYgov_test.doc) title(Model 4 Marginal Effects)
asdoc margins, at(nonISISinternalbansdi_lag=1  nonISISinternalbansdi_lag_syria=1 ISISinternalbansdi_lag=0 ISISinternalbansdi_lag_syria=0 syria=1 iraq=0), append save(8.i2CNTYgov_test.doc) title(Model 4 Marginal Effects)



**A18. LOCKDOWN-POPULATION OR BASE INTERACTIONS SUBSETTED BY COUNTRY (IRAQ and SYRIA) (Egypt: Insufficient Variation)**

**Model 1**
gen nonISIScurfewsdi_pop = nonISIScurfewsdi_lag*population
gen ISIScurfewsdi_pop = ISIScurfewsdi_lag*population
xtnbreg isisandlikely_wk covid19eradeath_lag  vsisis_wk_lag oilprice_lag nonISIScurfewsdi_lag nonISIScurfewsdi_pop ISIScurfewsdi ISIScurfewsdi_lag population ramadan if iraq==1, re
outreg2 using 9.iPOPBASESUBSETgov.doc, replace e(ll) 2aster bdec(2) sdec(2) bfmt(f) ctitle("all events (Iraq)")  title("Lockdown Interactions Subsetted by Country")
test nonISIScurfewsdi_pop nonISIScurfewsdi_lag pop 
asdoc test nonISIScurfewsdi_pop nonISIScurfewsdi_lag pop, replace save(9.iPOPBASESUBSETgov_test.doc) title(Model 1 Wald Test)
asdoc margins, at(ISIScurfewsdi_lag=0 nonISIScurfewsdi_lag=1 nonISIScurfewsdi_pop=100000  population=100000), append save(9.iPOPBASESUBSETgov_test.doc) title(Model 1 Marginal Effects)
asdoc margins, at(ISIScurfewsdi_lag=0 nonISIScurfewsdi_lag=1 nonISIScurfewsdi_pop=1000000 population=1000000), append save(9.iPOPBASESUBSETgov_test.doc) title(Model 1 Marginal Effects)

**Model 2**
xtnbreg isisandlikely_wk covid19eradeath_lag  vsisis_wk_lag oilprice_lag nonISIScurfewsdi_lag nonISIScurfewsdi_pop ISIScurfewsdi_pop ISIScurfewsdi_lag population ramadan if syria==1, re
outreg2 using 9.iPOPBASESUBSETgov.doc, append e(ll) 2aster bdec(2) sdec(2) bfmt(f) ctitle("all events (Syria)")  title("Lockdown Interactions Subsetted by Country")
test nonISIScurfewsdi_pop nonISIScurfewsdi_lag pop 
asdoc test nonISIScurfewsdi_pop nonISIScurfewsdi_lag pop ISIScurfewsdi_lag ISIScurfewsdi_pop, append save(9.iPOPBASESUBSETgov_test.doc) title(Model 2 Wald Test)
asdoc margins, at(ISIScurfewsdi_lag=0 ISIScurfewsdi_pop=0 nonISIScurfewsdi_lag=1 nonISIScurfewsdi_pop=100000  population=100000), append save(9.iPOPBASESUBSETgov_test.doc) title(Model 2 Marginal Effects)
asdoc margins, at(ISIScurfewsdi_lag=0 ISIScurfewsdi_pop=0 nonISIScurfewsdi_lag=1 nonISIScurfewsdi_pop=1000000 population=1000000), append save(9.iPOPBASESUBSETgov_test.doc) title(Model 2 Marginal Effects)

**Model 3**

gen nonISISinternalbansdi_base = nonISISinternalbansdi_lag*base
gen ISISinternalbansdi_base = ISISinternalbansdi_lag*base
xtnbreg isisandlikely_wk covid19eradeath_lag  vsisis_wk_lag oilprice_lag nonISISinternalbansdi_lag ISISinternalbansdi_lag ISISinternalbansdi_base nonISISinternalbansdi_base base ramadan if iraq==1, re
outreg2 using 9.iPOPBASESUBSETgov.doc, append e(ll) 2aster bdec(2) sdec(2) bfmt(f) ctitle("all events (Iraq)")  title("Lockdown Interactions Subsetted by Country")
asdoc test nonISISinternalbansdi_base nonISISinternalbansdi_lag base ISISinternalbansdi_lag ISISinternalbansdi_base, append save(9.iPOPBASESUBSETgov_test.doc) title(Model 3 Wald Test)
asdoc test nonISISinternalbansdi_base base nonISISinternalbansdi_lag, append save(9.iPOPBASESUBSETgov_test.doc) title(Model 3 Wald Test)
asdoc margins, at(nonISISinternalbansdi_lag=1 nonISISinternalbansdi_base=0 ISISinternalbansdi_lag=0 ISISinternalbansdi_base=0 base=0), append save(9.iPOPBASESUBSETgov_test.doc) title(Model 3 Marginal Effects)
asdoc margins, at(nonISISinternalbansdi_lag=1 nonISISinternalbansdi_base=1 ISISinternalbansdi_lag=0 ISISinternalbansdi_base=0 base=1), append save(9.iPOPBASESUBSETgov_test.doc) title(Model 3 Marginal Effects)

**Model 4**
xtnbreg isisandlikely_wk covid19eradeath_lag  vsisis_wk_lag oilprice_lag nonISISinternalbansdi_lag ISISinternalbansdi_lag ISISinternalbansdi_base nonISISinternalbansdi_base base ramadan if syria==1, re
outreg2 using 9.iPOPBASESUBSETgov.doc, append e(ll) 2aster bdec(2) sdec(2) bfmt(f) ctitle("all events (Syria)")  title("Lockdown Interactions Subsetted by Country")
asdoc test nonISISinternalbansdi_lag onISISinternalbansdi_base ISISinternalbansdi_lag ISISinternalbansdi_base base, append save(9.iPOPBASESUBSETgov_test.doc) title(Model 4 Wald Test)
asdoc test nonISISinternalbansdi_base nonISISinternalbansdi_lag base, append save(9.iPOPBASESUBSETgov_test.doc) title(Model 4 Wald Test)
asdoc margins, at(nonISISinternalbansdi_lag=1 nonISISinternalbansdi_base=0 ISISinternalbansdi_lag=0 ISISinternalbansdi_base=0 base=0), append save(9.iPOPBASESUBSETgov_test.doc) title(Model 4 Marginal Effects)
asdoc margins, at(nonISISinternalbansdi_lag=1 nonISISinternalbansdi_base=1 ISISinternalbansdi_lag=0 ISISinternalbansdi_base=0 base=1), append save(9.iPOPBASESUBSETgov_test.doc) title(Model 4 Marginal Effects)


* A19. DROPPING ALL GOVERNORATES THAT NEVER HAD AN ISIS ATTACK IN THIS PERIOD*


bysort iso govadmcode: gen sum = sum(isisandlikely_wk)
drop if sum == 0

*Model 1
xtnbreg isisandlikely_wk covid19eradeath_lag vsisis_wk_lag oilprice_lag nonISIScurfewsdi_lag ISIScurfewsdi_lag ramadan iraq egypt, re
outreg2 using 10.NOZEROS.doc, replace e(ll) 2aster bdec(2) sdec(2) bfmt(f) ctitle("all events")  title("Lockdowns Dropping All Governorates without Attacks")
asdoc test nonISIScurfewsdi_lag ISIScurfewsdi_lag, replace save(10.NOZEROS_test.doc) title(Model 1 Wald Test)
asdoc margins, at(nonISIScurfewsdi_lag=0 ISIScurfewsdi_lag=0), replace  save(10.NOZEROS_test.doc) title(Model 1 Marginal Effects)
asdoc margins, at(nonISIScurfewsdi_lag=1 ISIScurfewsdi_lag=0), append  save(10.NOZEROS_test.doc) title(Model 1 Marginal Effects)


*Model 2
gen nonISIScurfewsdi_pop = nonISIScurfewsdi_lag*population
gen ISIScurfewsdi_pop = ISIScurfewsdi_lag*population
xtnbreg isisandlikely_wk covid19eradeath_lag vsisis_wk_lag oilprice_lag nonISIScurfewsdi_lag nonISIScurfewsdi_pop ISIScurfewsdi_pop ISIScurfewsdi_lag population ramadan iraq egypt, re
outreg2 using 10.NOZEROS.doc, append e(ll) 2aster bdec(2) sdec(2) bfmt(f) ctitle("all events")  title("Lockdowns Dropping All Governorates without Attacks")
asdoc test nonISIScurfewsdi_pop nonISIScurfewsdi_lag pop ISIScurfewsdi_lag ISIScurfewsdi_pop, append save(10.NOZEROS_test.doc) title(Model 2 Wald Test) 
asdoc margins, at(ISIScurfewsdi_lag=0 ISIScurfewsdi_pop=0 nonISIScurfewsdi_lag=1 nonISIScurfewsdi_pop=100000  population=100000), append save(9.iPOPBASESUBSETgov_test.doc) title(Model 2 Marginal Effects)
asdoc margins, at(ISIScurfewsdi_lag=0 ISIScurfewsdi_pop=0 nonISIScurfewsdi_lag=1 nonISIScurfewsdi_pop=1000000 population=1000000), append save(9.iPOPBASESUBSETgov_test.doc) title(Model 2 Marginal Effects)

*Model 3
gen nonISISinternalbansdi_base = nonISISinternalbansdi_lag*base
gen ISISinternalbansdi_base = ISISinternalbansdi_lag*base
xtnbreg isisandlikely_wk covid19eradeath_lag vsisis_wk_lag oilprice_lag nonISISinternalbansdi_lag ISISinternalbansdi_lag ramadan iraq egypt, re
outreg2 using 10.NOZEROS.doc, append e(ll) 2aster bdec(2) sdec(2) bfmt(f) ctitle("all events")  title("Lockdowns Dropping All Governorates without Attacks")
asdoc test nonISISinternalbansdi_lag ISISinternalbansdi_lag, append save(10.NOZEROS_test.doc) title(Model 3 Wald Test) 
asdoc margins, at(nonISISinternalbansdi_lag=0 ISISinternalbansdi_lag=0), append save(10.NOZEROS_test.doc) title(Model 3 Marginal Effects)
asdoc margins, at(nonISISinternalbansdi_lag=1 ISISinternalbansdi_lag=0), append save(10.NOZEROS_test.doc) title(Model 3 Marginal Effects)

*Model 4
gen nonISISinternalbansdi_base  = base*nonISISinternalbansdi_lag
xtnbreg isisandlikely_wk covid19eradeath_lag vsisis_wk_lag oilprice_lag nonISISinternalbansdi_lag ISISinternalbansdi_lag ISISinternalbansdi_base nonISISinternalbansdi_base base ramadan iraq egypt, re
outreg2 using 10.NOZEROS.doc, append e(ll) 2aster bdec(2) sdec(2) bfmt(f) ctitle("all events")  title("Lockdowns Dropping All Governorates without Attacks")
asdoc  test nonISISinternalbansdi_base base nonISISinternalbansdi_lag, append save(10.NOZEROS_test.doc) title(Model 4 Wald Test) 
asdoc margins, at(nonISISinternalbansdi_base=0 base=0 nonISISinternalbansdi_lag=1), append save(10.NOZEROS_test.doc) title(Model 4 Marginal Effects)
asdoc margins, at(nonISISinternalbansdi_base=1 base=1 nonISISinternalbansdi_lag=1), append save(10.NOZEROS_test.doc) title(Model 4 Marginal Effects)



********************************************************************************************************
********************************************************************************************************
********************************************************************************************************
************ NATIONAL LEVEL, OTHER COUNTRIES WITH ANY PRESENCE OF ISIS AND/OR ITS AFFILIATES ***********
********************************************************************************************************
********************************************************************************************************

clear
use "LDV_SupplementaryData"


*Time-Set the Data
xtset monthnoyear 

*Generate Country Fixed Effects 

gen afghanistan = 0 
replace afghanistan = 1 if iso == 4 
gen algeria = 0 
replace algeria = 1 if iso  == 12
gen bangladesh = 0 
replace bangladesh = 1 if iso  == 50
gen cameroon = 0 
replace cameroon = 1 if iso  == 120
gen chad = 0 
replace chad = 1 if iso  == 148
gen drc = 0 
replace drc = 1 if iso  == 180
gen india = 0 
replace india = 1 if iso  == 356
gen indonesia = 0 
replace indonesia = 1 if iso  == 360
gen israel = 0 
replace israel = 1 if iso  == 376
gen lebanon = 0 
replace lebanon = 1 if iso  == 422
gen libya = 0 
replace libya = 1 if iso  == 434
gen mali = 0 
replace mali = 1 if iso  == 466
gen morocco = 0 
replace morocco = 1 if iso  == 504
gen niger = 0 
replace niger = 1 if iso  == 562
gen nigeria = 0 
replace nigeria = 1 if iso  == 566
gen pakistan = 0 
replace pakistan = 1 if iso  == 586
gen philippines = 0 
replace philippines = 1 if iso  == 608
gen russia = 0 
replace russia = 1 if iso  == 643
gen somalia = 0 
replace somalia = 1 if iso  == 706
gen tajikistan = 0 
replace tajikistan = 1 if iso  == 762
gen bfaso = 0 
replace bfaso = 1 if iso  == 854
gen yemen = 0 
replace yemen = 1 if iso  == 887


sort iso week 
foreach variable of varlist ramadan covid19eracase covid19eradeath oilprice   {
bysort iso: gen `variable'_lag = `variable'[_n-1]
destring, replace
}


************************************************************* ANALYSIS ********************************************************************** 


*All Countries, COVID19 ERA**
xtnbreg isisandlikely_wk covid19eradeath_lag  vsisis_wklag oilprice_lag ramadan afghanistan algeria bangladesh cameroon chad drc india indonesia israel lebanon libya mali morocco niger nigeria pakistan philippines russia somalia tajikistan bfaso yemen, re
outreg2 using 1.OTHERS.doc, replace e(ll) 2aster bdec(2) sdec(2) bfmt(f) ctitle("all events")  title("COVID19 Pandemic, Other Countries") 

*All Countries, COVID19 ERA**
xtnbreg isisandlikelyfatal_wk covid19eradeath_lag  vsisis_wklag oilprice_lag ramadan afghanistan algeria bangladesh cameroon chad drc india indonesia israel lebanon libya mali morocco niger nigeria pakistan philippines russia somalia tajikistan bfaso yemen, re
outreg2 using 1.OTHERS.doc, append e(ll) 2aster bdec(2) sdec(2) bfmt(f) ctitle("all events")  title("COVID19 Pandemic, Other Countries") 



**A21-24 INTERACTIONS FOR EACH OTHER COUNTRIES*

foreach X of varlist afghanistan-yemen {
gen covid_`X' = covid19eradeath_lag*`X'
}

*Model T1.1*
xtnbreg isisandlikely_wk covid19eradeath_lag  vsisis_wklag oilprice_lag ramadan covid_afghanistan afghanistan algeria bangladesh cameroon chad drc india indonesia israel lebanon libya mali morocco niger nigeria pakistan philippines russia somalia tajikistan bfaso yemen, re
outreg2 using 1.iOTHERS1.doc, replace e(ll) 2aster bdec(2) sdec(2) bfmt(f) ctitle("all events")  title("COVID19 Pandemic, Other Countries") 
asdoc test covid19eradeath_lag afghanistan covid_afghanistan, replace save(1.iOTHERS1_test.doc) title(Model 1 Wald Test)

*Model T1.2*
xtnbreg isisandlikely_wk covid19eradeath_lag  vsisis_wklag oilprice_lag ramadan covid_algeria afghanistan algeria bangladesh cameroon chad drc india indonesia israel lebanon libya mali morocco niger nigeria pakistan philippines russia somalia tajikistan bfaso yemen, re
outreg2 using 1.iOTHERS1.doc, append e(ll) 2aster bdec(2) sdec(2) bfmt(f) ctitle("all events")  title("COVID19 Pandemic, Other Countries") 
asdoc test covid19eradeath_lag algeria covid_algeria, append save(1.iOTHERS1_test.doc) title(Model 2 Wald Test)

*Model T1.3*
xtnbreg isisandlikely_wk covid19eradeath_lag  vsisis_wklag oilprice_lag ramadan covid_bangladesh afghanistan algeria bangladesh cameroon chad drc india indonesia israel lebanon libya mali morocco niger nigeria pakistan philippines russia somalia tajikistan bfaso yemen, re
outreg2 using 1.iOTHERS1.doc, append e(ll) 2aster bdec(2) sdec(2) bfmt(f) ctitle("all events")  title("COVID19 Pandemic, Other Countries") 
asdoc test covid19eradeath_lag bangladesh covid_bangladesh, append save(1.iOTHERS1_test.doc) title(Model 3 Wald Test)

*Model T1.4*
xtnbreg isisandlikely_wk covid19eradeath_lag  vsisis_wklag oilprice_lag ramadan covid_cameroon afghanistan algeria bangladesh cameroon chad drc india indonesia israel lebanon libya mali morocco niger nigeria pakistan philippines russia somalia tajikistan bfaso yemen, re
outreg2 using 1.iOTHERS1.doc, append e(ll) 2aster bdec(2) sdec(2) bfmt(f) ctitle("all events")  title("COVID19 Pandemic, Other Countries") 
asdoc test covid19eradeath_lag cameroon covid_cameroon, append save(1.iOTHERS1_test.doc) title(Model 4 Wald Test)

*Model T1.5*
xtnbreg isisandlikely_wk covid19eradeath_lag  vsisis_wklag oilprice_lag ramadan covid_chad afghanistan algeria bangladesh cameroon chad drc india indonesia israel lebanon libya mali morocco niger nigeria pakistan philippines russia somalia tajikistan bfaso yemen, re
outreg2 using 1.iOTHERS1.doc, append e(ll) 2aster bdec(2) sdec(2) bfmt(f) ctitle("all events")  title("COVID19 Pandemic, Other Countries") 
asdoc test covid19eradeath_lag chad covid_chad, append save(1.iOTHERS1_test.doc) title(Model 5 Wald Test)


*Model T2.1*
xtnbreg isisandlikely_wk covid19eradeath_lag  vsisis_wklag oilprice_lag ramadan  covid_india afghanistan algeria bangladesh cameroon chad drc india indonesia israel lebanon libya mali morocco niger nigeria pakistan philippines russia somalia tajikistan bfaso yemen, re
outreg2 using 2.iOTHERS2.doc, replace e(ll) 2aster bdec(2) sdec(2) bfmt(f) ctitle("all events")  title("COVID19 Pandemic, Other Countries") 
asdoc test covid19eradeath_lag india covid_india, replace save(2.iOTHERS2_test.doc) title(Model 1 Wald Test)

*Model T2.2*
xtnbreg isisandlikely_wk covid19eradeath_lag  vsisis_wklag oilprice_lag ramadan covid_indonesia afghanistan algeria bangladesh cameroon chad drc india indonesia israel lebanon libya mali morocco niger nigeria pakistan philippines russia somalia tajikistan bfaso yemen, re
outreg2 using 2.iOTHERS2.doc, append e(ll) 2aster bdec(2) sdec(2) bfmt(f) ctitle("all events")  title("COVID19 Pandemic, Other Countries") 
asdoc  test covid19eradeath_lag indonesia covid_indonesia, append save(2.iOTHERS2_test.doc) title(Model 2 Wald Test)

*Model T2.3*
xtnbreg isisandlikely_wk covid19eradeath_lag  vsisis_wklag oilprice_lag ramadan covid_israel afghanistan algeria bangladesh cameroon chad drc india indonesia israel lebanon libya mali morocco niger nigeria pakistan philippines russia somalia tajikistan bfaso yemen, re
outreg2 using 2.iOTHERS2.doc, append e(ll) 2aster bdec(2) sdec(2) bfmt(f) ctitle("all events")  title("COVID19 Pandemic, Other Countries") 
asdoc  test covid19eradeath_lag israel covid_israel, append save(2.iOTHERS2_test.doc) title(Model 3 Wald Test)

*Model T2.4*
xtnbreg isisandlikely_wk covid19eradeath_lag  vsisis_wklag oilprice_lag ramadan covid_lebanon afghanistan algeria bangladesh cameroon chad drc india indonesia israel lebanon libya mali morocco niger nigeria pakistan philippines russia somalia tajikistan bfaso yemen, re
outreg2 using 2.iOTHERS2.doc, append e(ll) 2aster bdec(2) sdec(2) bfmt(f) ctitle("all events")  title("COVID19 Pandemic, Other Countries") 
asdoc test covid19eradeath_lag lebanon covid_lebanon, append save(2.iOTHERS2_test.doc) title(Model 4 Wald Test)

*Model T2.5*
xtnbreg isisandlikely_wk covid19eradeath_lag  vsisis_wklag oilprice_lag ramadan covid_libya afghanistan algeria bangladesh cameroon chad drc india indonesia israel lebanon libya mali morocco niger nigeria pakistan philippines russia somalia tajikistan bfaso yemen, re
outreg2 using 2.iOTHERS2.doc, append e(ll) 2aster bdec(2) sdec(2) bfmt(f) ctitle("all events")  title("COVID19 Pandemic, Other Countries") 
asdoc test covid19eradeath_lag libya covid_libya, append save(2.iOTHERS2_test.doc) title(Model 5 Wald Test)


*Model T3.1*
xtnbreg isisandlikely_wk covid19eradeath_lag  vsisis_wklag oilprice_lag ramadan covid_mali afghanistan algeria bangladesh cameroon chad drc india indonesia israel lebanon libya mali morocco niger nigeria pakistan philippines russia somalia tajikistan bfaso yemen, re
outreg2 using 3.iOTHERS3.doc, replace e(ll) 2aster bdec(2) sdec(2) bfmt(f) ctitle("all events")  title("COVID19 Pandemic, Other Countries") 
asdoc test covid19eradeath_lag mali covid_mali, replace save(3.iOTHERS3_test.doc) title(Model 1 Wald Test)

*Model T3.2*
xtnbreg isisandlikely_wk covid19eradeath_lag  vsisis_wklag oilprice_lag ramadan covid_morocco afghanistan algeria bangladesh cameroon chad drc india indonesia israel lebanon libya mali morocco niger nigeria pakistan philippines russia somalia tajikistan bfaso yemen, re
outreg2 using 3.iOTHERS3.doc, append e(ll) 2aster bdec(2) sdec(2) bfmt(f) ctitle("all events")  title("COVID19 Pandemic, Other Countries") 
asdoc test covid19eradeath_lag morocco covid_morocco, append save(3.iOTHERS3_test.doc) title(Model 2 Wald Test)

*Model T3.3*
*sig/pos
xtnbreg isisandlikely_wk covid19eradeath_lag  vsisis_wklag oilprice_lag ramadan covid_niger afghanistan algeria bangladesh cameroon chad drc india indonesia israel lebanon libya mali morocco niger nigeria pakistan philippines russia somalia tajikistan bfaso yemen, re
outreg2 using 3.iOTHERS3.doc, append  e(ll) 2aster bdec(2) sdec(2) bfmt(f) ctitle("all events")  title("COVID19 Pandemic, Other Countries") 
asdoc test covid19eradeath_lag niger covid_niger, append save(3.iOTHERS3_test.doc) title(Model 3 Wald Test)


*Model T3.4*
xtnbreg isisandlikely_wk covid19eradeath_lag  vsisis_wklag oilprice_lag ramadan covid_nigeria afghanistan algeria bangladesh cameroon chad drc india indonesia israel lebanon libya mali morocco niger nigeria pakistan philippines russia somalia tajikistan bfaso yemen, re
outreg2 using 3.iOTHERS3.doc, append e(ll) 2aster bdec(2) sdec(2) bfmt(f) ctitle("all events")  title("COVID19 Pandemic, Other Countries") 
asdoc test covid19eradeath_lag nigeria covid_nigeria, append save(3.iOTHERS3_test.doc) title(Model 5 Wald Test)


*Model T4.1*
xtnbreg isisandlikely_wk covid19eradeath_lag  vsisis_wklag oilprice_lag ramadan covid_pakistan afghanistan algeria bangladesh cameroon chad drc india indonesia israel lebanon libya mali morocco niger nigeria pakistan philippines russia somalia tajikistan bfaso yemen, re
outreg2 using 4.iOTHERS4.doc, replace e(ll) 2aster bdec(2) sdec(2) bfmt(f) ctitle("all events")  title("COVID19 Pandemic, Other Countries") 
asdoc test covid19eradeath_lag pakistan covid_pakistan, replace save(4.iOTHERS4_test.doc) title(Model 1 Wald Test)

*Model T4.2*
xtnbreg isisandlikely_wk covid19eradeath_lag  vsisis_wklag oilprice_lag ramadan covid_philippines afghanistan algeria bangladesh cameroon chad drc india indonesia israel lebanon libya mali morocco niger nigeria pakistan philippines russia somalia tajikistan bfaso yemen, re
outreg2 using 4.iOTHERS4.doc, append e(ll) 2aster bdec(2) sdec(2) bfmt(f) ctitle("all events")  title("COVID19 Pandemic, Other Countries") 
asdoc test covid19eradeath_lag philippines covid_philippines, append save(4.iOTHERS4_test.doc) title(Model 2 Wald Test)

*Model T4.3*
xtnbreg isisandlikely_wk covid19eradeath_lag  vsisis_wklag oilprice_lag ramadan covid_russia afghanistan algeria bangladesh cameroon chad drc india indonesia israel lebanon libya mali morocco niger nigeria pakistan philippines russia somalia tajikistan bfaso yemen, re
outreg2 using 4.iOTHERS4.doc, append e(ll) 2aster bdec(2) sdec(2) bfmt(f) ctitle("all events")  title("COVID19 Pandemic, Other Countries") 
asdoc test covid19eradeath_lag russia covid_russia, append save(4.iOTHERS4_test.doc) title(Model 3 Wald Test)

*Model T4.4*
xtnbreg isisandlikely_wk covid19eradeath_lag  vsisis_wklag oilprice_lag ramadan covid_somalia afghanistan algeria bangladesh cameroon chad drc india indonesia israel lebanon libya mali morocco niger nigeria pakistan philippines russia somalia tajikistan bfaso yemen, re
outreg2 using 4.iOTHERS4.doc, append e(ll) 2aster bdec(2) sdec(2) bfmt(f) ctitle("all events")  title("COVID19 Pandemic, Other Countries") 
asdoc test covid19eradeath_lag somalia covid_somalia, append save(4.iOTHERS4_test.doc) title(Model 4 Wald Test)

*Model T4.5*
xtnbreg isisandlikely_wk covid19eradeath_lag  vsisis_wklag oilprice_lag ramadan covid_tajikistan afghanistan algeria bangladesh cameroon chad drc india indonesia israel lebanon libya mali morocco niger nigeria pakistan philippines russia somalia tajikistan bfaso yemen, re
outreg2 using 4.iOTHERS4.doc, append e(ll) 2aster bdec(2) sdec(2) bfmt(f) ctitle("all events")  title("COVID19 Pandemic, Other Countries") 
asdoc  test covid19eradeath_lag tajikistan covid_tajikistan, append save(4.iOTHERS4_test.doc) title(Model 5 Wald Test)

*Model T4.6*
xtnbreg isisandlikely_wk covid19eradeath_lag  vsisis_wklag oilprice_lag ramadan covid_bfaso afghanistan algeria bangladesh cameroon chad drc india indonesia israel lebanon libya mali morocco niger nigeria pakistan philippines russia somalia tajikistan bfaso yemen, re
outreg2 using 4.iOTHERS4.doc, append e(ll) 2aster bdec(2) sdec(2) bfmt(f) ctitle("all events")  title("COVID19 Pandemic, Other Countries") 
asdoc test covid19eradeath_lag bfaso covid_bfaso, append save(4.iOTHERS4_test.doc) title(Model 6 Wald Test)


